/*
1) все Serial.print и Serial.println в этом скетче закомментированы.
2) Везде в скетче используется 6 светодиодов на адресной светодиодной ленте WS2812, если используется другая лента или другое кол-во светодиодов, то надо это поменять.
кол-во светодиодов в ленте присутствует в цикле 
	for (int i=0; i<6; i++){
    leds[i]=ledColorBlack;
	}
где 6 - это и есть количество светодиодов на ленте.

Общее описание:
Подключено 3 кнопки, 2 реле и светодиодная лента, реагирующие на нажатие кнопок.
Используется библиотека алекса гайвера для кнопок, чтобы не было проблем с дребезгом кнопок и в послеюущем фиксировать НЕоднократные нажатия кнопок для управления светодиодной лентой, её яркостью и цветом.
Полное Управление светодиодной лентой ещё не реализовано. 
При одиночном нажатии на третью кнопку (пин 44) включается светодиодна лента с яркостью 30 (пин 47) и загорается светодиод красным цветом (пин 45). Если повторно нажать третью кнопку (пин 44), то выключится светодиодная лента (пин 47) и светодиод (пин 47) потухнет.
При двойном нажатии на третью кнопку (пин 44), то мы переходим в режим программирования яркости светодиодной ленты, при этом загорается информационный синий светодиод (пин 39), при  повторном нажатии третьей кнопки (пин 44), мы выйдем из режима программирования яркости и синий светодиод (пин 39) потухнет. Находясь в режиме программирования светодиодная лента по одиночному нажатию на третью кнопку (пин 44) увеличивает яркость
от 0 до 5
от 5 до 15
от 15 до 30
от 30 до 50
от 50 до 70
от 70 до 80
от 80 до 90
от 90 до 100
от 100 до 0
Установив желаемую яркость, выходим из режима программирования яркости светодиодной ленты двойным кликом на третью кнопку (пин 44).
Тройным нажатием на третью кнопку (пин 44) можно менять цвет светодиодной ленты.
Четверное нажати на третью кнопку (пин 44) сбрасывает настройки до следующих параметров:
1) лента выключена, но установлена яркость 5 для последующего включения и цвет белый
2) светодиод сигнаизирующий о режиме программирования и статусе (включена/выключена) светодиодной ленты вЫключен.

Светодиод используется RGB с общим анодом (с общим плюсом).
|	|	|	|
|	|	|	|
красн	|	синий
	|  зелен
	|
	|
	+
	5V
Через веб-интерфейс на http://10.36.1.72/ можно менять уровень яркости светодиодной ленты и её цвет, а так же контролировать эти показатели, то есть знать какой уровень яркости у включенной светодиодной ленты и каким цветом она светится.
Управление ИК пультом я не удалял, хотя практика показала, что за 4 года я этим функционалом ни разу не воспользовался.
*/
#include "GyverButton.h"
#include <Ethernet.h>
#include "IRremote.h"

IRrecv irrecv(7); // Указываем пин, к которому подключен ИК-приемник
decode_results results; // строка для ИК-приёма

// для rgb ленты
#include "FastLED.h"
// количество светодиодов в ленте
#define NUM_LEDS 144
#define COLOR_ORDER GRB
#define DATA_PIN 47		// к пину 47покдлючен din светодиодной ленты
CRGB leds[NUM_LEDS];
long ledColorWhite = 0xffffff;   // белый (основной цвет)
long ledColorBlack = 0x000000; // Чёрный (выключаем ленту)
long ledColor  = 0xffffff;// цвет светодиодной ленты, который будет меняться кнопками
long ledColorBlue = 0x0000FF;   // Синий цвет
long ledColorRed = 0xFF0000;   // Красный цвет
long ledColorGreen = 0x008000;   // Зелёный цвет
byte initialBrightness = 0;		// начальный уровень яркости светодиодной ленты
byte brightnessLevel = 5;		// Переменная значения уровня яркости лампы (0-минимум яркости, 100-максимум яркости). Можно использовать int вместо byte.
int ledLight[] = {0,5,15,30,50,70,80,90,100};		// массив с уровнем яркости от 0 до 100
boolean SettingsMode = 0;		// Переменная, характеризующая, зашли мы в режим настроек уровня яркости или нет
boolean SettingsColorMode = 0;		// Переменная, характеризующая, зашли мы в режим настроек цвета или нет
// для rgb ленты конец

// задаем константы
const int ledPinA =  41;     // номер выхода светодиода "А"
GButton myButtA(40);    // номер входа, подключенный к кнопке "А"
const int RelayA = 46;       // к 5-ому пину подключено IN1 реле "А"
const int ledPinB = 43;     // номер выхода светодиода "B"
GButton myButtB(42);    // номер входа, подключенный к кнопке "B"
const int RelayB = 48;       // к 5-ому пину подключено IN1 реле "B"
GButton myButtC(44);    // номер входа, подключенный к кнопке "С"
const int ledPinC = 45;     // номер выхода светодиода "C"
const int ledPinCP = 39;     // номер выхода светодиода "CP", показывает находимся ли мы в режиме программирования. Если горит синим, то мы в режиме программирования.

// переменные
boolean ledAOn = false;         // Текущее состояние светодиода "A" (включен/выключен)
boolean RelayAOn = false;        // Текущее состояние реле
boolean ledBOn = false;         // Текущее состояние светодиода "B" (включен/выключен)
boolean RelayBOn = false;        // Текущее состояние реле
boolean ledCOn = true;         // Текущее состояние светодиода "C" (включен/выключен)
boolean ledCPOn = true;         // Текущее состояние светодиода "CP" (включен/выключен
boolean ledStripLight = false;	// Текущее состояние светодиодной ленты (включена/выключена)

String readString = String(30);


// объявляем переменную MY_IP со значением 10.36.1.72 - это IP-адрес назначаемый сетевому модулю Arduino
#define MY_IP "10.36.1.72"
// указываем настройки сетевого интерфейса и порт веб-сервера
// mac - это mac-адрес назначаемый сетевому модулю Arduino
byte mac[] = { 0xDE, 0xAD, 0xBE, 0xEF, 0xFE, 0x1F };
// в IPAddress ещё раз указываем IP-адрес
IPAddress ip(10, 36, 1, 72);
EthernetServer server(80);


void setup() {
  delay(500);
  // HIGH_PULL - кнопка подключена к GND, пин подтянут к VCC (PIN --- КНОПКА --- GND)
  // LOW_PULL  - кнопка подключена к VCC, пин подтянут к GND
  myButtA.setType(LOW_PULL);
  myButtB.setType(LOW_PULL);
  myButtC.setType(LOW_PULL);
  
// указываем время для защиты от дребезга (30 мс) (!!! не должен быть больше myButt.setTimeout)
	myButtA.setDebounce(30);
	myButtB.setDebounce(30);
	myButtC.setDebounce(30);
// NORM_OPEN - нормально-разомкнутая кнопка
// NORM_CLOSE - нормально-замкнутая кнопка
  myButtA.setDirection(NORM_OPEN);
  myButtB.setDirection(NORM_OPEN);
  myButtC.setDirection(NORM_OPEN);
  
// Запускаем прием с ИК
irrecv.enableIRIn();
  
/*
 * без строки "digitalWrite(RelayA, LOW);" перед "pinMode" при включении
 * ардуины будет происходить кратковременное переключение реле,
 * а значит кратковременно подастся питание, что нам категорически
 * не надо!
 */
  digitalWrite(RelayA, LOW);
  digitalWrite(RelayB, LOW);
  
	// инициализируем пин, подключенный к светодиоду "A", как выход
	pinMode(ledPinA, OUTPUT);
	// инициализируем пин, подключенный к реле "A", как выход
	pinMode(RelayA, OUTPUT);
	// инициализируем пин, подключенный к светодиоду "B", как выход
	pinMode(ledPinB, OUTPUT);
	// инициализируем пин, подключенный к реле "B", как выход
	pinMode(RelayB, OUTPUT);
	// инициализируем пин, подключенный к светодиоду "C", как выход
	digitalWrite(ledPinC, HIGH);
	pinMode(ledPinC, OUTPUT);
  	// инициализируем пин, подключенный к светодиоду "CP", как выход
	digitalWrite(ledPinCP, HIGH);
	pinMode(ledPinCP, OUTPUT);
  
  
// светодиодная лента
LEDS.addLeds<WS2813, DATA_PIN, COLOR_ORDER>(leds, NUM_LEDS); // Set LED strip type
// верхнюю строку можно написать и как-будто у нас светодиодная лента ws2812, оно тоже вроде как работает
LEDS.setBrightness(initialBrightness); // устанавливаем яркость светодиодной ленты 0 при загрузке ардуно
// включаем все светодиоды с 0 по NUM_LEDS в цвет = ledColorBlack (в чёрный цвет, то есть выключаем)
	for (int i=0; i<NUM_LEDS; i++){
    leds[i]=ledColorBlack;
	}
FastLED.show();
// светодиодная лента конец
	
// стартуем сетевой интерфейс
Ethernet.begin(mac, ip);
server.begin();


Serial.begin(9600);
Serial.println("START ");
//Serial.print("server is at ");
//Serial.println(Ethernet.localIP());

// по окончании загрузки, быстро включаем все светодиоды и сразу выключаем
digitalWrite(ledPinA, HIGH);
digitalWrite(ledPinB, HIGH);
digitalWrite(ledPinC, LOW);
delay(250);
digitalWrite(ledPinA, LOW);
digitalWrite(ledPinB, LOW);
digitalWrite(ledPinC, HIGH);
}



void loop() {
myButtA.tick();  // обязательная функция отработки. Должна постоянно опрашиваться
myButtB.tick();  // обязательная функция отработки. Должна постоянно опрашиваться
myButtC.tick();  // обязательная функция отработки. Должна постоянно опрашиваться


// часть кода для кнопки "A", реле "A" и светодиода "A"
if (myButtA.isSingle())		// Если нажатие кнопки "A"
{
  ledAOn = !ledAOn;
  RelayAOn = !RelayAOn;
//  Serial.println("RelayA");
}
digitalWrite(ledPinA, ledAOn);                         // Изменить статус состояния светодиода "A"
digitalWrite(RelayA, RelayAOn);                         // Изменить статус состояния реле "A"


// часть кода для кнопки "B", реле "B" и светодиода "B"
if (myButtB.isSingle())		// Если нажатие  кнопки "B"
{
  ledBOn = !ledBOn;
  RelayBOn = !RelayBOn;
//  Serial.println("RelayB");
}
digitalWrite(ledPinB, ledBOn);                         // Изменить статус состояния светодиода "B"
digitalWrite(RelayB, RelayBOn);                         // Изменить статус состояния реле "B"





/// светодиодная лента, кнопка и светодиод.
// подсчёт колличества нажатий кнопки
	if (myButtC.hasClicks()) {
		byte clicks = myButtC.getClicks();
		switch (clicks) {
// если одинарный клик
			case 1:
//			Serial.println("BTN 3 -> 1 Click");

/////////////// если режим программирования выключен:
if (SettingsMode==0){
	
// если светодиодная лента не включена:
if (ledStripLight==false){
//Serial.println("BTN 3 -> 1 Click. NO settings mode 1");
digitalWrite(ledPinCP, HIGH);	// вЫключаем светодиод, режима программирования		
LEDS.setBrightness(brightnessLevel); // устанавливаем яркость в значение brightnessLevel
// включаем все светодиоды с 0 по NUM_LEDS в цвет = ledColor (изначально в белый цвет)
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColor;
}
FastLED.show();
ledCOn = LOW;
digitalWrite(ledPinC, ledCOn);                         // Изменить статус состояния светодиода "C"
ledStripLight=true;



}
// а вот если светодиодная лента включена
else
{
//Serial.println("BTN 3 -> 1 Click. NO settings mode 2");
digitalWrite(ledPinCP, HIGH);	// выключаем светодиод, режима программирования		
LEDS.setBrightness(initialBrightness); // устанавливаем 0
// включаем все светодиоды с 0 по NUM_LEDS в цвет = ledColorBlack (в чёрный цвет, то есть выключаем)
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColorBlack;
		}
FastLED.show();
//ledCOn = !ledCOn;
ledCOn = HIGH;
digitalWrite(ledPinC, ledCOn);                         // Изменить статус состояния светодиода "C"	
ledStripLight=false;
	}
	
}

/////////////// если режим программирования включен:
if (SettingsMode==1){
	
//	Serial.print("SettingsMode==1 && brightnessLevel: ");
//	Serial.println(brightnessLevel);
	
	LEDS.setBrightness(brightnessLevel);
for (int i=0; i<NUM_LEDS; i++){
		leds[i]=ledColor;
		}
		FastLED.show();
		ledStripLight=true;
		
//Serial.println("BTN 3 -> 1 Click on settings mode");

/////////////////////////// ЯРКОСТЬ ОТ 0 ДО 5
// если яркость (brightnessLevel) меньше 5 и не равна 5
if (brightnessLevel < 5 && brightnessLevel != 5){
//	Serial.println("BTN 3 -> 1 Settings mode -> UP from 0 to 5");
// величиваем значение "brightnessLevel" с 0 до 5 постепенно на +1 значение
   for (brightnessLevel=0; brightnessLevel <= 4; brightnessLevel++){
		for (int i=0; i<NUM_LEDS; i++){
		leds[i]=ledColor;
		}
// устанавливаем яркость светодиодной ленты
	LEDS.setBrightness(brightnessLevel);
// зажигаем светодиоды с яркостью "brightnessLevel"
	FastLED.show();
// ставим флажок включенной светодиодной ленты:
	ledStripLight=true;
// в com=порт выводим значение меняющегося "brightnessLevel"
//	Serial.print("brightnessLevel: ");
//	Serial.println(brightnessLevel);
		}
}
/////////////////////////// ЯРКОСТЬ ОТ 5 ДО 15
// если яркость (brightnessLevel) равна 5 или меньше 15
else if (brightnessLevel == 5 || brightnessLevel < 15){
//	Serial.println("BTN 3 -> 1 Settings mode -> UP from 5 to 15");
// величиваем значение "brightnessLevel" с 5 до 15 постепенно на +1 значение
   for (brightnessLevel=6; brightnessLevel <= 14; brightnessLevel++){
		for (int i=0; i<NUM_LEDS; i++){
		leds[i]=ledColor;
		}
// устанавливаем яркость светодиодной ленты
	LEDS.setBrightness(brightnessLevel);
// зажигаем светодиоды с яркостью "brightnessLevel"
	FastLED.show();
// ставим флажок включенной светодиодной ленты:
	ledStripLight=true;
// в com=порт выводим значение меняющегося "brightnessLevel"
//	Serial.print("brightnessLevel: ");
//	Serial.println(brightnessLevel);
		}
}

/////////////////////////// ЯРКОСТЬ ОТ 15 ДО 30
// если яркость (brightnessLevel) равна 15 или меньше 30
else if (brightnessLevel == 15 || brightnessLevel < 30){
//	Serial.println("BTN 3 -> 1 Settings mode -> UP from 15 to 30");
// величиваем значение "brightnessLevel" с 15 до 30 постепенно на +1 значение
   for (brightnessLevel=16; brightnessLevel <= 29; brightnessLevel++){
		for (int i=0; i<NUM_LEDS; i++){
		leds[i]=ledColor;
		}
// устанавливаем яркость светодиодной ленты
	LEDS.setBrightness(brightnessLevel);
// зажигаем светодиоды с яркостью "brightnessLevel"
	FastLED.show();
// ставим флажок включенной светодиодной ленты:
	ledStripLight=true;
// в com=порт выводим значение меняющегося "brightnessLevel"
//	Serial.print("brightnessLevel: ");
//	Serial.println(brightnessLevel);
		}
}

/////////////////////////// ЯРКОСТЬ ОТ 30 ДО 50
// если яркость (brightnessLevel) равна 30 или меньше 50
else if (brightnessLevel == 30 || brightnessLevel < 50){
//	Serial.println("BTN 3 -> 1 Settings mode -> UP from 30 to 50");
// величиваем значение "brightnessLevel" с 30 до 50 постепенно на +1 значение
   for (brightnessLevel=31; brightnessLevel <= 49; brightnessLevel++){
		for (int i=0; i<NUM_LEDS; i++){
		leds[i]=ledColor;
		}
// устанавливаем яркость светодиодной ленты
	LEDS.setBrightness(brightnessLevel);
// зажигаем светодиоды с яркостью "brightnessLevel"
	FastLED.show();
// ставим флажок включенной светодиодной ленты:
	ledStripLight=true;
// в com=порт выводим значение меняющегося "brightnessLevel"
//	Serial.print("brightnessLevel: ");
//	Serial.println(brightnessLevel);
		}
}

/////////////////////////// ЯРКОСТЬ ОТ 50 ДО 70
// если яркость (brightnessLevel) равна 50 или меньше 70
else if (brightnessLevel == 50 || brightnessLevel < 70){
//	Serial.println("BTN 3 -> 1 Settings mode -> UP from 50 to 70");
// величиваем значение "brightnessLevel" с 50 до 70 постепенно на +1 значение
   for (brightnessLevel=51; brightnessLevel <= 69; brightnessLevel++){
		for (int i=0; i<NUM_LEDS; i++){
		leds[i]=ledColor;
		}
// устанавливаем яркость светодиодной ленты
	LEDS.setBrightness(brightnessLevel);
// зажигаем светодиоды с яркостью "brightnessLevel"
	FastLED.show();
// ставим флажок включенной светодиодной ленты:
	ledStripLight=true;
// в com=порт выводим значение меняющегося "brightnessLevel"
//	Serial.print("brightnessLevel: ");
//	Serial.println(brightnessLevel);
		}
}

/////////////////////////// ЯРКОСТЬ ОТ 70 ДО 80
// если яркость (brightnessLevel) равна 70 или меньше 80
else if (brightnessLevel == 70 || brightnessLevel < 80){
//	Serial.println("BTN 3 -> 1 Settings mode -> UP from 70 to 80");
// величиваем значение "brightnessLevel" с 50 до 70 постепенно на +1 значение
   for (brightnessLevel=71; brightnessLevel <= 79; brightnessLevel++){
		for (int i=0; i<NUM_LEDS; i++){
		leds[i]=ledColor;
		}
// устанавливаем яркость светодиодной ленты
	LEDS.setBrightness(brightnessLevel);
// зажигаем светодиоды с яркостью "brightnessLevel"
	FastLED.show();
// ставим флажок включенной светодиодной ленты:
	ledStripLight=true;
// в com=порт выводим значение меняющегося "brightnessLevel"
//	Serial.print("brightnessLevel: ");
//	Serial.println(brightnessLevel);
		}
}

/////////////////////////// ЯРКОСТЬ ОТ 80 ДО 90
// если яркость (brightnessLevel) равна 80 или меньше 90
else if (brightnessLevel == 80 || brightnessLevel < 90){
//	Serial.println("BTN 3 -> 1 Settings mode -> UP from 80 to 90");
// величиваем значение "brightnessLevel" с 80 до 90 постепенно на +1 значение
   for (brightnessLevel=81; brightnessLevel <= 89; brightnessLevel++){
		for (int i=0; i<NUM_LEDS; i++){
		leds[i]=ledColor;
		}
// устанавливаем яркость светодиодной ленты
	LEDS.setBrightness(brightnessLevel);
// зажигаем светодиоды с яркостью "brightnessLevel"
	FastLED.show();
// ставим флажок включенной светодиодной ленты:
	ledStripLight=true;
// в com=порт выводим значение меняющегося "brightnessLevel"
//	Serial.print("brightnessLevel: ");
//	Serial.println(brightnessLevel);
		}
}

/////////////////////////// ЯРКОСТЬ ОТ 90 ДО 100
// если яркость (brightnessLevel) равна 90 или меньше 100
else if (brightnessLevel == 90 || brightnessLevel < 99){
//	Serial.println("BTN 3 -> 1 Settings mode -> UP from 90 to 100");
// величиваем значение "brightnessLevel" с 90 до 100 постепенно на +1 значение
   for (brightnessLevel=91; brightnessLevel <= 99; brightnessLevel++){
		for (int i=0; i<NUM_LEDS; i++){
		leds[i]=ledColor;
		}
// устанавливаем яркость светодиодной ленты
	LEDS.setBrightness(brightnessLevel);
// зажигаем светодиоды с яркостью "brightnessLevel"
	FastLED.show();
// ставим флажок включенной светодиодной ленты:
	ledStripLight=true;
// в com=порт выводим значение меняющегося "brightnessLevel"
//	Serial.print("brightnessLevel: ");
//	Serial.println(brightnessLevel);
		}
}

/////////////////////////// ЯРКОСТЬ сбрасываем со 100 на 0
// если яркость (brightnessLevel) равна 100
else if (brightnessLevel == 100){
//	Serial.println("BTN 3 -> 1 Settings mode -> DOWN from 100 to 0");
// устанавливаем яркость светодиодной ленты
	LEDS.setBrightness(0);
// сбрасываем яркость на 0
		for (int i=0; i<NUM_LEDS; i++){
		leds[i]=ledColorBlack;
		}
//ставим яркость 0
brightnessLevel = 0;
// зажигаем светодиоды с яркостью "brightnessLevel"
	FastLED.show();
// ставим флажок включенной светодиодной ленты:
	ledStripLight=false;
// в com=порт выводим значение меняющегося "brightnessLevel"
//	Serial.print("brightnessLevel: ");
//	Serial.println(brightnessLevel);
}

}
			break;
			


// если двойной клик по кнопке управления светодиодной лентой
			case 2:
//			Serial.println("BTN 3 -> 2 Click -> Enter SettingsMode");
// переходим в режим программирования светодиодной лентой для настройки яркости:
			SettingsMode=!SettingsMode;
// если режим программирования яркости светодиодной ленты включен:
if (SettingsMode==1){
// 	вЫключаем светодиод красный
	digitalWrite(ledPinC, HIGH);
// 	включаем светодиод синий
	digitalWrite(ledPinCP, LOW);
}
else
{
	digitalWrite(ledPinCP, HIGH);
//	Serial.println("BTN 3 -> 2 Click -> Exit SettingsMode");
	// если светодиодная лента не включена
	if (ledStripLight==false){
		// вЫключаем светодиод обозначающий включённую светодиодную ленту
		digitalWrite(ledPinC, HIGH);
	}
	// если светодиодная лента включена
	else
	{
		// выключаем светодиод обозначающий включённую светодиодную ленту
		digitalWrite(ledPinC, LOW);
	}

}
		// если в режиме программирования (SettingsMode==1) светодиодная лента была вЫключена, то после настройки яркости и выхода из режима программирования, надо вЫключить обратно светодиодную ленту, не смотря на установленный уровень яркости:
	if (SettingsMode==0 && ledStripLight==false && brightnessLevel==5)
	{
		LEDS.setBrightness(initialBrightness);
		for (int i=0; i<NUM_LEDS; i++){
		leds[i]=ledColorBlack;
		}
		FastLED.show();
//	Serial.println("LED OFF: 5");
	}
		if (SettingsMode==0 && ledStripLight==false && brightnessLevel==15)
	{
		LEDS.setBrightness(initialBrightness);
		for (int i=0; i<NUM_LEDS; i++){
		leds[i]=ledColorBlack;
		}
		FastLED.show();
//	Serial.println("LED OFF: 15");
	}
			if (SettingsMode==0 && ledStripLight==false && brightnessLevel==30)
	{
		LEDS.setBrightness(initialBrightness);
		for (int i=0; i<NUM_LEDS; i++){
		leds[i]=ledColorBlack;
		}
		FastLED.show();
//	Serial.println("LED OFF: 30");
	}
			if (SettingsMode==0 && ledStripLight==false && brightnessLevel==50)
	{
		LEDS.setBrightness(initialBrightness);
		for (int i=0; i<NUM_LEDS; i++){
		leds[i]=ledColorBlack;
		}
		FastLED.show();
//	Serial.println("LED OFF: 50");
	}
			if (SettingsMode==0 && ledStripLight==false && brightnessLevel==70)
	{
		LEDS.setBrightness(initialBrightness);
		for (int i=0; i<NUM_LEDS; i++){
		leds[i]=ledColorBlack;
		}
		FastLED.show();
//	Serial.println("LED OFF: 70");
	}
			if (SettingsMode==0 && ledStripLight==false && brightnessLevel==80)
	{
		LEDS.setBrightness(initialBrightness);
		for (int i=0; i<NUM_LEDS; i++){
		leds[i]=ledColorBlack;
		}
		FastLED.show();
//	Serial.println("LED OFF: 80");
	}
			if (SettingsMode==0 && ledStripLight==false && brightnessLevel==90)
	{
		LEDS.setBrightness(initialBrightness);
		for (int i=0; i<NUM_LEDS; i++){
		leds[i]=ledColorBlack;
		}
		FastLED.show();
//	Serial.println("LED OFF: 90");
	}
			if (SettingsMode==0 && ledStripLight==false && brightnessLevel==100)
	{
		LEDS.setBrightness(initialBrightness);
		for (int i=0; i<NUM_LEDS; i++){
		leds[i]=ledColorBlack;
		}
		FastLED.show();
//	Serial.println("LED OFF: 100");
	}
			break;


// при тройном нажатии на кнопку управления светодиодной лентой:
			case 3:
			SettingsColorMode = 1;
//			Serial.println("BTN 3 -> 3 Click -> Change color");
// если находились в режиме программирования яркостью светодиодной ленты:
 if (SettingsMode==1) {
	 // то выходим из режима программирования светодиодной лентой:
//	Serial.println("BTN 3 -> 3 Click -> EXIT SettingsMode");
	SettingsMode=0;
}

// если цвет белый и режим смены цвета активен:
if (ledColor == ledColorWhite && SettingsColorMode==1) {
// если лента выключена или выключена (вообще можно убрать это условие):
if (ledStripLight==false || ledStripLight==true){
// Serial.println("BTN 3 -> 3 Click");
digitalWrite(ledPinCP, HIGH);	// вЫключаем светодиод режима программирования яркости
LEDS.setBrightness(brightnessLevel); // устанавливаем яркость от 1 до 100
// включаем все светодиоды с 0 по NUM_LEDS в цвет = ledColorBlue (в синий цвет)
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColorBlue;
}
FastLED.show();
ledCOn = LOW;
ledColor = ledColorBlue;
// меняем цвет на синий
digitalWrite(ledPinC, ledCOn);		// Изменить статус состояния светодиода "C"
ledStripLight=true;
}
// и выходим из режима смены цвета
SettingsColorMode=0;
}

// если цвет синий и режим смены цвета активен
else if (ledColor == ledColorBlue && SettingsColorMode==1) {
// если лента выключена
if (ledStripLight==false || ledStripLight==true){
// Serial.println("BTN 3 -> 3 Click");
digitalWrite(ledPinCP, HIGH);	// вЫключаем светодиод режима программирования яркости
LEDS.setBrightness(brightnessLevel); // устанавливаем яркость от 1 до 100
// включаем все светодиоды с 0 по NUM_LEDS в цвет = ledColorBlue (в синий цвет)
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColorGreen;
}
FastLED.show();
ledCOn = LOW;
// меняем цвет на зелёный
ledColor = ledColorGreen;
digitalWrite(ledPinC, ledCOn);		// Изменить статус состояния светодиода "C"
ledStripLight=true;
}
// и выходим из режима смены цветов
SettingsColorMode=0;
}

// если цвет зелёный и режим смены цвета активен
else if (ledColor == ledColorGreen && SettingsColorMode==1) {
// если лента выключена
if (ledStripLight==false || ledStripLight==true){
// Serial.println("BTN 3 -> 3 Click");
digitalWrite(ledPinCP, HIGH);	// вЫключаем светодиод режима программирования яркости
LEDS.setBrightness(brightnessLevel); // устанавливаем яркость от 1 до 100
// включаем все светодиоды с 0 по NUM_LEDS в цвет = ledColorBlue (в синий цвет)
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColorRed;
}
FastLED.show();
ledCOn = LOW;
// меняем цвет на красный
ledColor = ledColorRed;
digitalWrite(ledPinC, ledCOn);		// Изменить статус состояния светодиода "C"
ledStripLight=true;
}
// и выхоим из режима смены цветов
SettingsColorMode=0;
}

// если цвет красный и режим смены цвета активен
else if (ledColor == ledColorRed && SettingsColorMode==1) {
// если лента выключена
if (ledStripLight==false || ledStripLight==true){
// Serial.println("BTN 3 -> 3 Click");
digitalWrite(ledPinCP, HIGH);	// вЫключаем светодиод режима программирования яркости
LEDS.setBrightness(brightnessLevel); // устанавливаем яркость от 1 до 100
// включаем все светодиоды с 0 по NUM_LEDS в цвет = ledColorBlue (в синий цвет)
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColorWhite;
}
FastLED.show();
ledCOn = LOW;
// меняем цвет на белый
ledColor = ledColorWhite;
digitalWrite(ledPinC, ledCOn);		// Изменить статус состояния светодиода "C"
ledStripLight=true;
}
// и выходим из режима смены цветов
SettingsColorMode=0;
}
			break;


			case 4:
// при нажатии на кнопку управления светодиодной лентой 4 раза:
//Serial.println("BTN 3 -> 4 Click -> Reset");
// сбрасываем настойки светодиодной ленты:
ledStripLight=false;
ledColor = ledColorWhite;
digitalWrite(ledPinC, HIGH);
digitalWrite(ledPinCP, HIGH);
// устанавливаем уровень яркости светодиодной ленты после сброса по 4-ёх кратному нажатию.
brightnessLevel=5;
LEDS.setBrightness(brightnessLevel);
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColorBlack;
}
FastLED.show();
			break;

		}
	}
/// светодиодная лента и кнопка конец



// сетевой интерфейс на шилде с w5100
  EthernetClient client = server.available();
   if (client) {
//    Serial.println("new client");
    while (client.connected()) {
      if (client.available()) {
        char c = client.read();
//        Serial.write(c);

if (readString.length() < 30) {
readString.concat( c); }
//Serial.print( c);


if (c == '\n') {
/////////// реле А начало
//Проверяем включили ли реле "A" и светодиод "A"?
//LevelA=1 - включен реле и светодиод "А"
//LevelA=0 - выключен реле и светодиод "А"
if(readString.indexOf("LevelA=1") >=0) {
//Включаем реле "A"
digitalWrite(RelayA, HIGH);
RelayAOn = true;
//Включаем светодиод "A"
digitalWrite(ledPinA, HIGH);
ledAOn = true;

}else if(readString.indexOf("LevelA=0") >=0){
//Выключаем реле "A"
digitalWrite(RelayA, LOW);
RelayAOn = false;
//Выключаем светодиод "A"
digitalWrite(ledPinA, LOW);
ledAOn = false;
}
/////////// реле А конец

/////////// реле B начало
//Проверяем включили ли реле "B" и светодиод "B"?
//LevelB=1 - включен реле и светодиод "B"
//LevelB=0 - выключен реле и светодиод "B"
if(readString.indexOf("LevelB=1") >=0) {
//Включаем реле "B"
digitalWrite(RelayB, HIGH);
RelayBOn = true;
//Включаем светодиод "B"
digitalWrite(ledPinB, HIGH);
ledBOn = true;

}else if(readString.indexOf("LevelB=0") >=0){
//Выключаем реле "B"
digitalWrite(RelayB, LOW);
RelayBOn = false;
//Выключаем светодиод "B"
digitalWrite(ledPinB, LOW);
ledBOn = false;
}
/////////// реле B конец

/////////////////// управление светодиодной лентой по web начало
// яркость светодиодной ленты:
if(readString.indexOf("ledLight=off") >=0) {
digitalWrite(ledPinC, HIGH);
SettingsMode=0;
digitalWrite(ledPinCP, HIGH);
LEDS.setBrightness(brightnessLevel);
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColorBlack;
}
FastLED.show();
ledStripLight=false;
}

if(readString.indexOf("ledLight=0") >=0) {
digitalWrite(ledPinC, HIGH);
SettingsMode=0;
digitalWrite(ledPinCP, HIGH);
brightnessLevel=0;
LEDS.setBrightness(brightnessLevel);
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColor;
}
FastLED.show();
ledStripLight=false;
}
if(readString.indexOf("ledLight=5") >=0) {
digitalWrite(ledPinC, LOW);
SettingsMode=0;
digitalWrite(ledPinCP, HIGH);
brightnessLevel=5;
LEDS.setBrightness(brightnessLevel);
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColor;
}
FastLED.show();
ledStripLight=true;
}
if(readString.indexOf("ledLight=15") >=0) {
digitalWrite(ledPinC, LOW);
SettingsMode=0;
digitalWrite(ledPinCP, HIGH);
brightnessLevel=15;
LEDS.setBrightness(brightnessLevel);
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColor;
}
FastLED.show();
ledStripLight=true;
}
if(readString.indexOf("ledLight=30") >=0) {
digitalWrite(ledPinC, LOW);
SettingsMode=0;
digitalWrite(ledPinCP, HIGH);
brightnessLevel=30;
LEDS.setBrightness(brightnessLevel);
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColor;
}
FastLED.show();
ledStripLight=true;
}
if(readString.indexOf("ledLight=50") >=0) {
digitalWrite(ledPinC, LOW);
SettingsMode=0;
digitalWrite(ledPinCP, HIGH);
brightnessLevel=50;
LEDS.setBrightness(brightnessLevel);
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColor;
}
FastLED.show();
ledStripLight=true;
}
if(readString.indexOf("ledLight=70") >=0) {
digitalWrite(ledPinC, LOW);
SettingsMode=0;
digitalWrite(ledPinCP, HIGH);
brightnessLevel=70;
LEDS.setBrightness(brightnessLevel);
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColor;
}
FastLED.show();
ledStripLight=true;
}
if(readString.indexOf("ledLight=80") >=0) {
digitalWrite(ledPinC, LOW);
SettingsMode=0;
digitalWrite(ledPinCP, HIGH);
brightnessLevel=80;
LEDS.setBrightness(brightnessLevel);
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColor;
}
FastLED.show();
ledStripLight=true;
}
if(readString.indexOf("ledLight=90") >=0) {
digitalWrite(ledPinC, LOW);
SettingsMode=0;
digitalWrite(ledPinCP, HIGH);
brightnessLevel=90;
LEDS.setBrightness(brightnessLevel);
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColor;
}
FastLED.show();
ledStripLight=true;
}
if(readString.indexOf("ledLight=100") >=0) {
digitalWrite(ledPinC, LOW);
SettingsMode=0;
digitalWrite(ledPinCP, HIGH);
brightnessLevel=100;
LEDS.setBrightness(brightnessLevel);
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColor;
}
FastLED.show();
ledStripLight=true;
}
if(readString.indexOf("ledLight=on") >=0) {
digitalWrite(ledPinC, LOW);
SettingsMode=0;
digitalWrite(ledPinCP, HIGH);
LEDS.setBrightness(brightnessLevel);
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColor;
}
FastLED.show();
ledStripLight=true;
}

// цвет светодиодной ленты:
if(readString.indexOf("ledLight=white") >=0) {
digitalWrite(ledPinC, LOW);
SettingsMode=0;
digitalWrite(ledPinCP, HIGH);
ledColor=ledColorWhite;
LEDS.setBrightness(brightnessLevel);
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColor;
}
FastLED.show();
ledStripLight=true;
}

if(readString.indexOf("ledLight=blue") >=0) {
digitalWrite(ledPinC, LOW);
SettingsMode=0;
digitalWrite(ledPinCP, HIGH);
ledColor=ledColorBlue;
LEDS.setBrightness(brightnessLevel);
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColor;
}
FastLED.show();
ledStripLight=true;
}

if(readString.indexOf("ledLight=green") >=0) {
digitalWrite(ledPinC, LOW);
SettingsMode=0;
digitalWrite(ledPinCP, HIGH);
ledColor=ledColorGreen;
LEDS.setBrightness(brightnessLevel);
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColor;
}
FastLED.show();
ledStripLight=true;
}

if(readString.indexOf("ledLight=red") >=0) {
digitalWrite(ledPinC, LOW);
SettingsMode=0;
digitalWrite(ledPinCP, HIGH);
ledColor=ledColorRed;
LEDS.setBrightness(brightnessLevel);
for (int i=0; i<NUM_LEDS; i++){
leds[i]=ledColor;
}
FastLED.show();
ledStripLight=true;
}
//////////////////// управление светодиодной лентой по web конец

client.println("HTTP/1.1 200 OK");
client.println("Content-Type: text/html");
client.println("Connection: close");  // the connection will be closed after completion of the response
//client.println("Refresh: 5");  // refresh the page automatically every 5 sec
client.println();
client.println("<!DOCTYPE HTML>");
client.println("<html>");
client.println("<meta http-equiv='Content-Type' content='text/html; charset=utf-8' /> ");
client.println("<head><meta http-equiv=\"refresh\" content=\"5;URL=http://"MY_IP"/\"></head>");
client.println(F("<body>"));
client.println(F("<center><head>"));
client.println(F("<title>Relay Control</title>"));

// добавляем красивости
client.println(F("<style>"));
// стиль цвета состояния реле
client.println(F("RColor {font-size: 100%;"));
client.println(F("font-family: Verdana, Arial, Helvetica, sans-serif;")); 
client.println(F("color: #FF0000;}"));

client.println(F("GColor {font-size: 100%;"));
client.println(F("font-family: Verdana, Arial, Helvetica, sans-serif;")); 
client.println(F("color: #008000;}"));

client.println(F("BColor {font-size: 100%;"));
client.println(F("font-family: Verdana, Arial, Helvetica, sans-serif;")); 
client.println(F("color: #0000FF;}"));

client.println(F("WColor {font-size: 100%;"));
client.println(F("font-family: Verdana, Arial, Helvetica, sans-serif;")); 
client.println(F("color: #808080;}"));

// стиль таблицы с кнопками компакстный
client.println(F("table {"));
//client.println(F("  border-spacing: 0px;"));
client.println(F("  border-radius: 10px;"));
client.println(F("	background: #ccc;}"));
client.println(F("}"));
client.println(F("table td input {"));
client.println(F("  display: inline-block;"));
client.println(F("  text-decoration: none;"));
client.println(F("  padding: 1em;"));
client.println(F("  outline: none;"));
//client.println(F("  border-radius: 10px;"));
client.println(F("}"));
client.println(F("table td a {"));
client.println(F("  display: inline-block;"));
client.println(F("  text-decoration: none;"));
client.println(F("  background: #ccc;"));
client.println(F("	color: #000;"));
client.println(F("  padding: 1em;"));
client.println(F("  outline: none;"));
client.println(F("  border-radius: 10px;"));
client.println(F("  border: 1px solid #999;"));
client.println(F("}"));

client.println(F("</style>"));


client.println(F("</head>"));
/////////////////////////// Relay A begin
if (RelayAOn){
client.println("<form method=get name=LEDA>");
client.println("<input type=radio name=LevelA value=1>Включить");
client.println("<input type=radio name=LevelA value=0 CHECKED>Выключить");
client.println("<input type=submit value=Применить>");
client.println("</form>");
client.println("<font size=’5′>Состояние реле: ");
client.println("<font size=’5′><RColor>Вкл.</RColor>");
client.println("<br></br>");
}else{
client.println("<form method=get name=LEDA>");
client.println("<input type=radio name=LevelA value=1 CHECKED>Включить");
client.println("<input type=radio name=LevelA value=0>Выключить");
client.println("<input type=submit value=Применить>");
client.println("</form>");
client.println("<font size=’5′>Состояние реле: ");
client.println("<font size=’5′><GColor>Выкл</GColor>");
client.println("<br></br>");
}
/////////////////////////// Relay A end

/////////////////////////// Relay B begin
if (RelayBOn){
client.println("<form method=get name=LEDB>");
client.println("<input type=radio name=LevelB value=1>Включить");
client.println("<input type=radio name=LevelB value=0 CHECKED>Выключить");
client.println("<input type=submit value=Применить>");
client.println("</form>");
client.println("<font size=’5′>Состояние реле: ");
client.println("<font size=’5′><RColor>Вкл.</RColor>");
client.println("<br></br>");
}else{
client.println("<form method=get name=LEDB>");
client.println("<input type=radio name=LevelB value=1 CHECKED>Включить");
client.println("<input type=radio name=LevelB value=0>Выключить");
client.println("<input type=submit value=Применить>");
client.println("</form>");
client.println("<font size=’5′>Состояние реле: ");
client.println("<font size=’5′><GColor>Выкл</GColor>");
client.println("<br></br>");
}
////////////////////////// Relay B end

// управление реле кнопками на web-интерфейсе
client.print(F("<input type=button value='Light 1 ON' onmousedown=location.href='/?LevelA=1'>"));
client.println("&emsp;");
client.println(F("<input type=button value='Light 1 OFF' onmousedown=location.href='/?LevelA=0'><br/><br/>"));
client.print(F("<input type=button value='Light 2 ON' onmousedown=location.href='/?LevelB=1'>"));
client.println("&emsp;");
client.println(F("<input type=button value='Light 2 OFF' onmousedown=location.href='/?LevelB=0'><br/><br/>"));

// таблица с кнопками управления яркости на web-интерфейсе
client.println("<table>");
client.println("	<tr>");
	client.println("	<td><a href=\"/?ledLight=on\"\">ON</a></td>");
	client.println("	<td><a href=\"/?ledLight=100\"\">100</a></td>");
	client.println("	<td><a href=\"/?ledLight=90\"\">90</a></td>");
	client.println("	<td><a href=\"/?ledLight=80\"\">80</a></td>");
	client.println("	<td><a href=\"/?ledLight=70\"\">70</a></td>");
	client.println("	<td><a href=\"/?ledLight=50\"\">50</a></td>");
	client.println("	<td><a href=\"/?ledLight=30\"\">30</a></td>");
	client.println("	<td><a href=\"/?ledLight=15\"\">15</a></td>");
	client.println("	<td><a href=\"/?ledLight=5\"\">5</a></td>");
	client.println("	<td><a href=\"/?ledLight=0\"\">0</a></td>");
	client.println("	<td><a href=\"/?ledLight=off\"\">OFF</a></td>");
client.println("	</tr>");
client.println("</table>");


client.print(F("<p>Текущее значение яркости: "));
client.println("<p></p>");
if (ledStripLight==false) {
client.print(F("Светодиодная лента вЫключена</p>"));
}
if (brightnessLevel==0 && ledStripLight==false) {
client.print(F("0</p>"));
}
if (brightnessLevel==0 && ledStripLight==true) {
client.print(F("0</p>"));
}
if (brightnessLevel==5 && ledStripLight==true) {
client.print(F("5</p>"));
}
if (brightnessLevel==15 && ledStripLight==true) {
client.print(F("15</p>"));
}
if (brightnessLevel==30 && ledStripLight==true) {
client.print(F("30</p>"));
}
if (brightnessLevel==50 && ledStripLight==true) {
client.print(F("50</p>"));
}
if (brightnessLevel==70 && ledStripLight==true) {
client.print(F("70</p>"));
}
if (brightnessLevel==80 && ledStripLight==true) {
client.print(F("80</p>"));
}
if (brightnessLevel==90 && ledStripLight==true) {
client.print(F("90</p>"));
}
if (brightnessLevel==100 && ledStripLight==true) {
client.print(F("100</p>"));
}
if (ledStripLight==true) {
client.print(F("Светодиодная лента включена</p>"));
}

client.print(F("<p>Режим программирования яркости кнопкой: "));
if (SettingsMode==true) {
client.print(F("ВКЛЮЧЕН</p>"));
}
if (SettingsMode==false) {
client.print(F("ВЫКЛЮЧЕН</p>"));
}

// таблица управления цветом светодиодной ленты на web-интерфейсе
client.println("<table>");
client.println("	<tr>");
	client.println("	<td><WColor><a href=\"/?ledLight=white\"\">белый</a></WColor></td>");
	client.println("	<td><BColor><a href=\"/?ledLight=blue\"\">синий</a></BColor></td>");
	client.println("	<td><GColor><a href=\"/?ledLight=green\"\">зелёный</a></GColor></td>");
	client.println("	<td><RColor><a href=\"/?ledLight=red\"\">красный</a></RColor></td>");
client.println("	</tr>");
client.println("</table>");

client.print(F("<p>Цвет светодиодной ленты: "));
if (ledColor == ledColorWhite) {
client.print(F("<WColor>белый</WColor></p>"));
}
if (ledColor == ledColorBlue) {
client.println("<BColor>синий</BColor></p>");
}
if (ledColor == ledColorGreen) {
client.println("<GColor>зелёный</GColor></p>");
}
if (ledColor == ledColorRed) {
client.println("<RColor>красный</RColor></p>");
}
////////////////////////// LED лента end

client.println(F("</center></body>"));
client.println("</html>");
readString="";
//останавливаем web-client
client.stop();
          }
        }
      }
    }


// часть кода для ИК, реле и светодиода
if (irrecv.decode(&results)) {
int value = results.value;
Serial.println(value, HEX);
/*
 * мы знаем, что у цифры 2 значение сигнала 20DF48B7
 */
if(value == 0x48B7)// Если нажата кнопка "2"
  {
    ledAOn = !ledAOn;
    RelayAOn = !RelayAOn;
  }
irrecv.resume();
	}
}
